#
# spec file for package lammps
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2018 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           lammps
Version:        20180316
%define         uversion stable_16Mar2018
Release:        lp152.3.10
Summary:        Molecular Dynamics Simulator
License:        GPL-2.0 and GPL-3.0+
Group:          Productivity/Scientific/Chemistry
Url:            http://lammps.sandia.gov
Source0:        https://github.com/lammps/lammps/archive/%{uversion}.tar.gz#/%{name}-%{uversion}.tar.gz
# PATCH-FIX-UPSTREAM 858.patch, https://github.com/lammps/lammps/pull/858 - fix return value on ppc64
Patch0:         https://github.com/lammps/lammps/pull/858.patch
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-devel
BuildRequires:  openmpi-devel
BuildRequires:  python-devel
BuildRequires:  fftw3-devel
BuildRequires:  voro++-devel
BuildRequires:  zlib-devel
BuildRequires:  gsl-devel
BuildRequires:  cmake
BuildRequires:  opencl-headers
BuildRequires:  ocl-icd-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LAMMPS is a classical molecular dynamics code, and an acronym for Large-scale 
Atomic/Molecular Massively Parallel Simulator.

LAMMPS has potentials for soft materials (biomolecules, polymers) and 
solid-state materials (metals, semiconductors) and coarse-grained or 
mesoscopic systems. It can be used to model atoms or, more generically, as a 
parallel particle simulator at the atomic, meso, or continuum scale.

LAMMPS runs on single processors or in parallel using message-passing 
techniques and a spatial-decomposition of the simulation domain. The code is 
designed to be easy to modify or extend with new functionality.

%package -n liblammps0
Summary:        LAMMPS library
Group:          System/Libraries

%description -n liblammps0
LAMMPS is a classical molecular dynamics code, and an acronym for Large-scale 
Atomic/Molecular Massively Parallel Simulator.

LAMMPS has potentials for soft materials (biomolecules, polymers) and 
solid-state materials (metals, semiconductors) and coarse-grained or 
mesoscopic systems. It can be used to model atoms or, more generically, as a 
parallel particle simulator at the atomic, meso, or continuum scale.

LAMMPS runs on single processors or in parallel using message-passing 
techniques and a spatial-decomposition of the simulation domain. The code is 
designed to be easy to modify or extend with new functionality.

This package contains the library of LAMMPS package.

%package devel
Summary:    Development headers and libraries for LAMMPS
Group:      Development/Libraries/C and C++
Requires:   liblammps0 = %{version}
Requires:   %{name} = %{version}

%description devel
LAMMPS is a classical molecular dynamics code, and an acronym for Large-scale 
Atomic/Molecular Massively Parallel Simulator.

LAMMPS has potentials for soft materials (biomolecules, polymers) and 
solid-state materials (metals, semiconductors) and coarse-grained or 
mesoscopic systems. It can be used to model atoms or, more generically, as a 
parallel particle simulator at the atomic, meso, or continuum scale.

LAMMPS runs on single processors or in parallel using message-passing 
techniques and a spatial-decomposition of the simulation domain. The code is 
designed to be easy to modify or extend with new functionality.

This package contains development headers and libraries for LAMMPS.

%package -n python-%{name}
Summary:    LAMMPS python module
Group:      Development/Languages/Python
Requires:   liblammps0 = %{version}

%description -n python-%{name}
LAMMPS is a classical molecular dynamics code, and an acronym for Large-scale 
Atomic/Molecular Massively Parallel Simulator.

LAMMPS has potentials for soft materials (biomolecules, polymers) and 
solid-state materials (metals, semiconductors) and coarse-grained or 
mesoscopic systems. It can be used to model atoms or, more generically, as a 
parallel particle simulator at the atomic, meso, or continuum scale.

LAMMPS runs on single processors or in parallel using message-passing 
techniques and a spatial-decomposition of the simulation domain. The code is 
designed to be easy to modify or extend with new functionality.

This subpackage contains LAMMPS's Python module.

%prep
%setup -q -n %{name}-%{uversion}
%patch0 -p1

%build
source %{_libdir}/mpi/gcc/openmpi/bin/mpivars.sh

%{cmake} -DENABLE_ALL=ON -DENABLE_MPI=ON -DENABLE_PYTHON=ON -DENABLE_TESTING=ON -DENABLE_VORONOI=ON -DENABLE_GPU=ON -DGPU_API=OpenCL -DFFT=FFTW3 -DPYTHON_INSTDIR=%{python_sitearch} ../cmake
make %{?_smp_mflags}

%install
%cmake_install

%check
LD_LIBRARY_PATH='%{buildroot}/%{_libdir}:%{_libdir}/mpi/gcc/openmpi/%{_lib}' make -C build %{?_smp_mflags} test ARGS=-V

%post -n liblammps0 -p /sbin/ldconfig
%postun -n liblammps0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE README
%{_bindir}/lmp

%files -n liblammps0
%defattr(-,root,root,-)
%{_libdir}/liblammps.so.*

%files devel
%defattr(-,root,root)
%doc LICENSE
%{_includedir}/%{name}
%{_libdir}/liblammps.so
%{_libdir}/pkgconfig/liblammps.pc

%files -n python-%{name}
%defattr(-,root,root,-)
%{python_sitearch}/%{name}.py

%changelog
* Wed Mar 28 2018 junghans@votca.org
- bump version to 20180316 (stable)
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * A potentially harmful bug was found and fixed in the pair_style reax/c command
- Added 858.patch to fix return value on ppc64
* Thu Mar  8 2018 junghans@votca.org
- bump version to 20180308
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * Various small changes and bug fixes in preparation for a new stable version release
* Mon Mar  5 2018 junghans@votca.org
- bump version to 20180222
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * added a pair lj/cut/coul/wolf command to enable Wolf treatment of Coulombic
  * added a new USER-MOFFF package which is an implementation of the MOF-FF (MOF force field)
  * added a new pair_style ufm command
* Sat Jan 27 2018 junghans@votca.org
- bump version 20180117
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * new pair yukawa/kk command
  * new fix python/move command for time integration in Python
  * new pair extep command
  * tools/doxygen directory to build a Doxygen style call graph and API lists for LAMMPS
  * new pair snap/kk and pair zbl/kk commands
  * update of Kokkos library
  * improvements to pair reax/c command
  * new info coeffs command option
  * much faster replicate command for large systems when using many processors
  * improved setup performance for large systems on many processors with molecules and pppm
  * more informative error messages when evaluating variables
- dropped 30b482975a6a29db2265b44c4f27d6293eacb72f.patch, got merged
* Fri Jan 19 2018 junghans@votca.org
- fix python install for openSUSE Factory
* Sat Nov  4 2017 junghans@votca.org
- enable GPU support via OpenCL
- added 30b482975a6a29db2265b44c4f27d6293eacb72f.patch
* Wed Oct 25 2017 junghans@votca.org
- bump version 20171023
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * added a new USER-UEF package
  * added a fix rhok command
  * added a bond_style gromos command compatible with the GROMOS force field.
  * added coreshell variants of the pair born/coul/wolf and pair coul/wolf potentials to the CORESHELL package.
* Wed Oct 25 2017 junghans@votca.org
- adapt to new openlmi package - source mpivars.h during build
* Mon Sep 11 2017 junghans@votca.org
- changes license to GPL-2.0 and GPL-3.0+ (#522368)
* Fri Sep  8 2017 junghans@votca.org
- bump version to 20170901
- drop 573.diff, got merge upstream
- many little bugfxes: http://lammps.sandia.gov/bug.html
  * added USER-MESO package
  * new compute aggregate/atom and compute fragment/atom commands
* Tue Aug 15 2017 junghans@votca.org
- bump version to 20170811
- many little bugfxes: http://lammps.sandia.gov/bug.html
* Mon Jul 24 2017 jengelh@inai.de
- RPM group fix.
* Fri Jul 21 2017 junghans@votca.org
- bump version of 20170706 and move to cmake (upstream 573.diff)
- Notable new features in this release are:
  * refactoring of the neighbor list construction to be more modular and extensible from packages. active neighbor list modules
    are reported in the output
  * updates, performance improvements and new styles for the KOKKOS and USER-INTEL packages
  * bugfixes and refactoring of parts of AIREBO and AIREBO-M addressing some of the occasionally observed instabilities with the
    LAMMPS implementation
  * new interface to Multi-Scale Coarse-Graining tools of the Voth group via new MSCG package with fix mscg
  * new pair styles lj/charmmfsw/coul/charmmfsh and lj/charmmfsw/coul/long and dihedral style charmmfsh for improved
    compatibility with the CHARMM code using recent versions of the CHARMM force field
  * several new styles in the USER-MISC package
  * improved compatibility with Python 3 (now only the PYTHON package is still Python 2 only), improvements to PyLammps and its
    documentation
  * various updates and performance improvements for USER-DPD package
  * updates and bugfixes to USER-COLVARS
  * new package USER-CGDNA for coarse grained DNA simulations
  * new support for generalized replica exchange (gREM) via temper/grem and fix grem commands
  * support for treating spherical particles as 2d discs
  * improvements for load balancing via recursive bisectioning
  * new SNAP potential for tungsten and tungsten/helium systems
  * updated version of the bundled moltemplate tool
  * updated tutorial for submitting additions and changes to LAMMPS via GitHub
  * improvements to the documentation build tools
  * ambiguous hyperlinks in documentation are made unique
  * spellchecked documentation and comments
  * removed the obsolete xmovie software
  * many little cleanups, bug fixes and removal of dead or obsolete code, including in the tools folder
* Tue Apr 23 2013 scorot@free.fr
- first package
